# Editing Keys

When Windows Git is waiting for input from the user, the following keys have special meanings:

Delete | Delete the character under the cursor.
Backspace | Delete the character to the left of the cursor.
Home | Move the cursor to the start of the input line.
End | Move the cursor to the end of the input line.
Cursor Left | Move the cursor to the left.
Cursor Right | Move the cursor to the right.
Cursor Up | Show the previous input in the input history.
Cursor Down | Show the next input in the input history.
Ctrl+Cursor Left | Move the cursor to the start of the current word, or the previous word if already at the start of a word.
Ctrl+Cursor Right | Move the cursor to the end of the current word, or the next word if already at the end of a word.
Tab | Move the input focus to the next window which is waiting for input.
Shift+Tab | Move the input focus to the previous window which is waiting for input.
Ctrl+Pause | Halts any speech currently being spoken.
| Ctrl+V | Paste the contents of the clipboard into the input line.
Alt+Enter | Toggle full screen mode.

The hotkeys assigned to menu items are given here.